@@ -1,6 +1,6 @@
 package Email::Sender;
 # ABSTRACT: a library for sending email
-$Email::Sender::VERSION = '1.300019'; # TRIAL
+$Email::Sender::VERSION = '1.300022'; # TRIAL
 use Moo::Role;
 requires 'send';
 
@@ -68,7 +68,7 @@ Email::Sender - a library for sending email
 
 =head1 VERSION
 
-version 1.300019
+version 1.300022
 
 =head1 SYNOPSIS
 
@@ -123,7 +123,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Efros Aristotle Pagaltzis Christian Walde David Golden Steinbrunner Hans Dieter Pearcey HIROSE Masaaki Justin Hunter Kenichi Ishigaki kga Kris Matthews William Blunn
+=for stopwords Alex Efros Aristotle Pagaltzis Christian Walde David Golden Steinbrunner Fayland Lam Hans Dieter Pearcey HIROSE Masaaki Justin Hunter Kenichi Ishigaki kga Kris Matthews Wes Malone William Blunn
 
 =over 4
 
@@ -149,6 +149,10 @@ David Steinbrunner <dsteinbrunner@pobox.com>
 
 =item *
 
+Fayland Lam <fayland@gmail.com>
+
+=item *
+
 Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
@@ -173,13 +177,17 @@ Kris Matthews <kris@tigerlms.com>
 
 =item *
 
+Wes Malone <wes@mitsi.com>
+
+=item *
+
 William Blunn <zgpmax@cpan.org>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
