@@ -1,7 +1,8 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300019'; # TRIAL
+$Email::Sender::Transport::SMTP::VERSION = '1.300022'; # TRIAL
 use Moo;
+use Try::Tiny;
 
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
@@ -14,7 +15,7 @@ use utf8 (); # See below. -- rjbs, 2015-05-14
 #pod =head1 DESCRIPTION
 #pod
 #pod This transport is used to send email over SMTP, either with or without secure
-#pod sockets (SSL).  It is one of the most complex transports available, capable of
+#pod sockets (SSL/TLS).  It is one of the most complex transports available, capable of
 #pod partial success.
 #pod
 #pod For a potentially more efficient version of this transport, see
@@ -28,9 +29,9 @@ use utf8 (); # See below. -- rjbs, 2015-05-14
 #pod
 #pod =item C<host>: the name of the host to connect to; defaults to C<localhost>
 #pod
-#pod =item C<ssl>: if true, connect via SSL; defaults to false
+#pod =item C<ssl>: 'ssl' / 'starttls' / undef, if true, passed to L<Net::SMTPS> doSSL.
 #pod
-#pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for SSL
+#pod =item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl' and 587 for 'starttls'
 #pod
 #pod =item C<timeout>: maximum time in secs to wait for server; default is 120
 #pod
@@ -43,12 +44,14 @@ sub BUILD {
 }
 
 has host => (is => 'ro', isa => Str,  default => sub { 'localhost' });
-has ssl  => (is => 'ro', isa => Bool, default => sub { 0 });
+has ssl  => (is => 'ro', isa => Str);
 has port => (
   is  => 'ro',
   isa => Int,
   lazy    => 1,
-  default => sub { return $_[0]->ssl ? 465 : 25; },
+  default => sub {
+    return $_[0]->ssl && $_[0]->ssl eq 'starttls' ?  587 : $_[0]->ssl ? 465 : 25
+  },
 );
 
 has timeout => (is => 'ro', isa => Int, default => sub { 120 });
@@ -105,15 +108,32 @@ sub _smtp_client {
 
   my $class = "Net::SMTP";
   if ($self->ssl) {
-    require Net::SMTP::SSL;
-    $class = "Net::SMTP::SSL";
+    for (qw(Net::SMTPS Net::SMTP::SSL)) {
+      no warnings 'exiting';
+      try {
+        eval "require $_";
+        $class = $_;
+        last
+      };
+    }
+    Carp::croak(__PACKAGE__.": $class does not support starttls;".
+      " install Net::SMTPS for that")
+      if $class eq 'Net::SMTP::SSL' && $self->ssl eq 'starttls';
+    Carp::croak(__PACKAGE__.": SSL/TLS requires Net::SMTPS")
+      if $class eq 'Net::SMTP';
   } else {
     require Net::SMTP;
   }
 
   my $smtp = $class->new( $self->_net_smtp_args );
 
-  $self->_throw("unable to establish SMTP connection") unless $smtp;
+  unless ($smtp) {
+    $self->_throw(
+      sprintf "unable to establish SMTP connection to %s port %s",
+        $self->host,
+        $self->port,
+    );
+  }
 
   if ($self->sasl_username) {
     $self->_throw("sasl_username but no sasl_password")
@@ -134,11 +154,15 @@ sub _smtp_client {
 sub _net_smtp_args {
   my ($self) = @_;
 
+  # compatible
+  my $ssl = $self->ssl;
+  $ssl = 'ssl' if $self->ssl and $self->ssl ne 'starttls';
   return (
     $self->host,
     Port    => $self->port,
     Timeout => $self->timeout,
     Debug   => $self->debug,
+    defined $ssl             ? (doSSL     => $ssl)             : (),
     defined $self->helo      ? (Hello     => $self->helo)      : (),
     defined $self->localaddr ? (LocalAddr => $self->localaddr) : (),
     defined $self->localport ? (LocalPort => $self->localport) : (),
@@ -262,6 +286,17 @@ sub _message_complete { $_[1]->quit; }
 #pod may return L<Email::Sender::Success::Partial> objects.  Consult that module's
 #pod documentation.
 #pod
+#pod =head1 EXAMPLES
+#pod
+#pod =head2 send email with Gmail
+#pod
+#pod   my $smtp  = Email::Sender::Transport::SMTP->new({
+#pod     host => 'smtp.gmail.com',
+#pod     ssl  => 'starttls',
+#pod     sasl_username => 'myaccount@gmail.com',
+#pod     sasl_password => 'mypassword',
+#pod   });
+#pod
 #pod =cut
 
 with 'Email::Sender::Transport';
@@ -280,12 +315,12 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300019
+version 1.300022
 
 =head1 DESCRIPTION
 
 This transport is used to send email over SMTP, either with or without secure
-sockets (SSL).  It is one of the most complex transports available, capable of
+sockets (SSL/TLS).  It is one of the most complex transports available, capable of
 partial success.
 
 For a potentially more efficient version of this transport, see
@@ -299,9 +334,9 @@ The following attributes may be passed to the constructor:
 
 =item C<host>: the name of the host to connect to; defaults to C<localhost>
 
-=item C<ssl>: if true, connect via SSL; defaults to false
+=item C<ssl>: 'ssl' / 'starttls' / undef, if true, passed to L<Net::SMTPS> doSSL.
 
-=item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for SSL
+=item C<port>: port to connect to; defaults to 25 for non-SSL, 465 for 'ssl' and 587 for 'starttls'
 
 =item C<timeout>: maximum time in secs to wait for server; default is 120
 
@@ -327,13 +362,24 @@ If C<allow_partial_success> was set when creating the transport, the transport
 may return L<Email::Sender::Success::Partial> objects.  Consult that module's
 documentation.
 
+=head1 EXAMPLES
+
+=head2 send email with Gmail
+
+  my $smtp  = Email::Sender::Transport::SMTP->new({
+    host => 'smtp.gmail.com',
+    ssl  => 'starttls',
+    sasl_username => 'myaccount@gmail.com',
+    sasl_password => 'mypassword',
+  });
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2016 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
